Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(141)

Unified Diff: media/blink/webmediaplayer_impl.cc

Issue 791233003: Generate OnPipelineSeeked event for seek to currenttime in pause state (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Modified comment Created 6 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: media/blink/webmediaplayer_impl.cc
diff --git a/media/blink/webmediaplayer_impl.cc b/media/blink/webmediaplayer_impl.cc
index 06eaa5a104eb3f993d563fbcf4951484d5090021..da8839f04d65d688b8762a0056c433f839df7a56 100644
--- a/media/blink/webmediaplayer_impl.cc
+++ b/media/blink/webmediaplayer_impl.cc
@@ -328,16 +328,19 @@ void WebMediaPlayerImpl::seek(double seconds) {
// Update our paused time.
// In paused state ignore the seek operations to current time and generate
// buffer state change event to eventually fire seeking and seeked events
if (paused_) {
if (paused_time_ != seek_time) {
paused_time_ = seek_time;
} else {
main_task_runner_->PostTask(
+ FROM_HERE, base::Bind(&WebMediaPlayerImpl::OnPipelineSeeked,
+ AsWeakPtr(), false, PIPELINE_OK));
+ main_task_runner_->PostTask(
FROM_HERE,
base::Bind(&WebMediaPlayerImpl::OnPipelineBufferingStateChanged,
- AsWeakPtr(),
- BUFFERING_HAVE_ENOUGH));
+ AsWeakPtr(), BUFFERING_HAVE_ENOUGH));
return;
}
}
@@ -328,16 +328,19 @@ void WebMediaPlayerImpl::seek(double seconds) {
// Update our paused time.
// In paused state ignore the seek operations to current time and generate
- // buffer state change event to eventually fire seeking and seeked events
+ // OnPipelineSeeked and OnPipelineBufferingStateChanged events
+ // to eventually fire seeking and seeked events
if (paused_) {
if (paused_time_ != seek_time) {
« no previous file with comments | « no previous file | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698